<?php
/**
 * Plugin Name: Print Page - Block
 * Description: Print the entire page with single click
 * Version: 1.0.5
 * Author: bPlugins LLC
 * Author URI: http://bplugins.com
 * License: GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain: print-page
 */

// ABS PATH
if ( !defined( 'ABSPATH' ) ) { exit; }

// Constant
define( 'PPB_PLUGIN_VERSION', 'localhost' === $_SERVER['HTTP_HOST'] ? time() : '1.0.5' );
define( 'PPB_ASSETS_DIR', plugin_dir_url( __FILE__ ) . 'assets/' );

// Print Page
class PPBPrintPage{
	function __construct(){
		add_action( 'init', [$this, 'onInit'] );
	}

	function onInit() {
		wp_register_style( 'ppb-print-page-editor-style', plugins_url( 'dist/editor.css', __FILE__ ), [ 'wp-edit-blocks' ], PPB_PLUGIN_VERSION ); // Backend Style
		wp_register_style( 'ppb-print-page-style', plugins_url( 'dist/style.css', __FILE__ ), [ 'wp-editor' ], PPB_PLUGIN_VERSION ); // Frontend Style

		register_block_type( __DIR__, [
			'editor_style'		=> 'ppb-print-page-editor-style',
			'style'				=> 'ppb-print-page-style',
			'render_callback'	=> [$this, 'render']
		] ); // Register Block
		
		wp_set_script_translations( 'ppb-print-page-editor-script', 'print-page', plugin_dir_path( __FILE__ ) . 'languages' ); // Translate
	}

	function render( $attributes ){
		extract( $attributes );

		ob_start(); ?>
		<div class='wp-block-ppb-print-page noPrint <?php echo 'align' . esc_attr( $align ); ?>' id='ppbPrintPage-<?php echo esc_attr( $cId ) ?>' data-attributes='<?php echo esc_attr( wp_json_encode( $attributes ) ); ?>'></div>

		<?php return ob_get_clean();
	} // Render
}
new PPBPrintPage;